<?php
namespace Bushelpowered\Api\Trade\Esign\V1\Model;
        
class UnsignedDocumentStandard implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp
{
    /** @var string $id The unique identifier of the document.*/
    public string $id;
    /** @var null|string $customerTag A customer-defined tag for the contract.*/
    public ?string $customerTag = null;
    /** @var null|string $accountName The name of the owner.*/
    public ?string $accountName = null;
    /** @var string $accountId The bushel account id of the signer.*/
    public string $accountId;
    /** @var string $previewUrl The URL to the document file.*/
    public string $previewUrl;
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureResponse[] $signatures */
    public array $signatures;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;

    /**
     * @param  string  $id The unique identifier of the document.
     * @param  null|string  $customerTag A customer-defined tag for the contract.
     * @param  null|string  $accountName The name of the owner.
     * @param  string  $accountId The bushel account id of the signer.
     * @param  string  $previewUrl The URL to the document file.
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureResponse[]  $signatures 
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, ?string $customerTag, ?string $accountName, string $accountId, string $previewUrl, array $signatures, string $createdAt, string $updatedAt)
    {
        $this->id = $id;
        $this->customerTag = $customerTag;
        $this->accountName = $accountName;
        $this->accountId = $accountId;
        $this->previewUrl = $previewUrl;
        $this->signatures = $signatures;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
}